ChunkStream

Type Alias ChunkStream 

pub type ChunkStream<T> = Pin<Box<dyn Stream<Item = Result<T>> + Send>>;
A stream of response chunks.

Boxed and pinned so it can be polled directly with futures_util::StreamExt, without the caller having to pin it first.

Aliased Type

pub struct ChunkStream<T> { /* private fields */ }